[gnome-shell] messageTray: Remove _fixMarkup() function



commit 01374989b1d72721aec1cd2294c4260da8278e15
Author: Florian Müllner <fmuellner gnome org>
Date:   Thu Jun 11 14:39:36 2015 +0200

    messageTray: Remove _fixMarkup() function
    
    Commit 053e54f944 copied it to calendar, and since commit 15e42c4d5,
    the original is no longer used.

 js/ui/messageTray.js |   20 --------------------
 tests/unit/markup.js |    8 ++++----
 2 files changed, 4 insertions(+), 24 deletions(-)
---
diff --git a/js/ui/messageTray.js b/js/ui/messageTray.js
index e0d6344..4f1ab7f 100644
--- a/js/ui/messageTray.js
+++ b/js/ui/messageTray.js
@@ -69,26 +69,6 @@ const Urgency = {
     CRITICAL: 3
 };
 
-function _fixMarkup(text, allowMarkup) {
-    if (allowMarkup) {
-        // Support &amp;, &quot;, &apos;, &lt; and &gt;, escape all other
-        // occurrences of '&'.
-        let _text = text.replace(/&(?!amp;|quot;|apos;|lt;|gt;)/g, '&amp;');
-
-        // Support <b>, <i>, and <u>, escape anything else
-        // so it displays as raw markup.
-        _text = _text.replace(/<(?!\/?[biu]>)/g, '&lt;');
-
-        try {
-            Pango.parse_markup(_text, -1, '');
-            return _text;
-        } catch (e) {}
-    }
-
-    // !allowMarkup, or invalid markup
-    return GLib.markup_escape_text(text, -1);
-}
-
 const FocusGrabber = new Lang.Class({
     Name: 'FocusGrabber',
 
diff --git a/tests/unit/markup.js b/tests/unit/markup.js
index 5862582..cf28972 100644
--- a/tests/unit/markup.js
+++ b/tests/unit/markup.js
@@ -1,6 +1,6 @@
 // -*- mode: js; js-indent-level: 4; indent-tabs-mode: nil -*-
 
 // Test cases for MessageTray markup parsing
 
 const JsUnit = imports.jsUnit;
 const Pango = imports.gi.Pango;
@@ -8,7 +8,7 @@ const Pango = imports.gi.Pango;
 const Environment = imports.ui.environment;
 Environment.init();
 
-const MessageTray = imports.ui.messageTray;
+const Calendar = imports.ui.calendar;
 
 // Assert that @input, assumed to be markup, gets "fixed" to @output,
 // which is valid markup. If @output is null, @input is expected to
@@ -16,7 +16,7 @@ const MessageTray = imports.ui.messageTray;
 function assertConverts(input, output) {
     if (!output)
         output = input;
-    let fixed = MessageTray._fixMarkup(input, true);
+    let fixed = Calendar._fixMarkup(input, true);
     JsUnit.assertEquals(output, fixed);
 
     let parsed = false;
@@ -30,7 +30,7 @@ function assertConverts(input, output) {
 // Assert that @input, assumed to be plain text, gets escaped to @output,
 // which is valid markup.
 function assertEscapes(input, output) {
-    let fixed = MessageTray._fixMarkup(input, false);
+    let fixed = Calendar._fixMarkup(input, false);
     JsUnit.assertEquals(output, fixed);
 
     let parsed = false;
@@ -1,6 +1,6 @@
 // -*- mode: js; js-indent-level: 4; indent-tabs-mode: nil -*-
 
-// Test cases for MessageTray markup parsing
+// Test cases for Calendar markup parsing
 
 const JsUnit = imports.jsUnit;


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]